<img src="https://raw.githubusercontent.com/creativecommons/cc-assets/main/license_badges/big/by_nc_nd.svg" width="90">

[![CodeQL](https://github.com/elden1337/peaqev-core/actions/workflows/codeql.yml/badge.svg)](https://github.com/elden1337/peaqev-core/actions/workflows/codeql.yml) [![Python application](https://github.com/elden1337/peaqev-core/actions/workflows/python-app.yml/badge.svg)](https://github.com/elden1337/peaqev-core/actions/workflows/python-app.yml) 
[![Downloads](https://img.shields.io/pypi/dm/peaqevcore.svg)](https://pypi.org/project/peaqevcore/)
[![Paypal](https://img.shields.io/badge/Sponsor-PayPal-orange.svg)](https://www.paypal.com/donate/?hosted_button_id=GLGW8QAAQC2FG)
[![BuyMeACoffee](https://img.shields.io/badge/Sponsor-BuyMeACoffee-orange.svg)](https://buymeacoffee.com/elden)

<img src="https://raw.githubusercontent.com/elden1337/hass-peaq/main/assets/icon.png" width="125">

## Core classes for Peaqev car charging.

https://pypi.org/project/peaqevcore/

Used in: https://github.com/elden1337/hass-peaq

---

### :cherries: Sponsorship and prioritized development :cherries:
Peaqev is developed without static funding. If you lack your locale/charger type or have wishes for other specific features that you would like to see prioritized, please consider becoming a [Github sponsor](https://github.com/sponsors/elden1337) to bump your desired changes in my backlog.
- In order to flag a ticket, either create a new one or comment on an existing one after you've started your sponsorship. I will then flag the ticket with `sponsored-change` and try to prioritize this going forward
- Becoming a sponsor is not a guarantee that a wish will be created, or a guarantee for a specified resolution time. Peaqev is being developed in my spare time and every feature has to be considered by me before taking it into development
- I may need to reach out for testing, especially if your wish includes implementing new charger types
- Critical bugs discovered of course always triages higher than features

:love_letter:

